@@ -1,13 +1,13 @@
 """
 :authors: Tarodictrl
 :license: MIT License, see LICENSE file
-:copyright: (c) 2023 Tarodictrl
+:copyright: (c) 2024 Tarodictrl
 """
 
 from .session import Timetable, Ocenka
-from .sdo import Notifications
+from .sdo import Notifications, Messages, User
 
 __author__ = "Tarodictrl"
-__version__ = "0.3.0"
+__version__ = "0.3.3"
 __license__ = "MIT License"
 __email__ = "vudi600@gmail.com"
