@@ -1,9 +1,13 @@
 from .exceptions import TusurError
 from .constants import AJAX_SERVICE_URL
+from requests import Session
 
 
 class Ajax:
-    def _ajax_send(self, params: dict, data: dict) -> dict:
+    def __init__(self, session: Session) -> None:
+        self.__session = session
+
+    def _send(self, params: dict, data: dict) -> dict:
         """
         Send an AJAX request to a specified URL
         with the provided parameters and data.
@@ -20,13 +24,13 @@ class Ajax:
             TusurError: If an error is encountered in the JSON response.
 
         Example:
-            ajax_instance = Ajax()
+            ajax_instance = Ajax(session)
             params = {'key': 'value'}
             data = {'data_key': 'data_value'}
-            response = ajax_instance._ajax_send(params, data)
+            response = ajax_instance._send(params, data)
         """
-        response = self._session.post(AJAX_SERVICE_URL,
-                                      params=params, json=data)
+        response = self.__session.post(AJAX_SERVICE_URL,
+                                       params=params, json=data)
 
         if response.status_code == 200:
             json_response = response.json()
